<?php

require_once "config.inc";
require_once "db.inc";
require_once "sessions.inc";
require_once "language.inc";
require_once "constants.inc";

function set_error_reporting()
{
	global $config;

	switch ($config['debug_level'])
	{
		case 0:
			error_reporting (0);
			break;
		case 1:
			error_reporting (E_ERROR);
			break;
		case 2:
			error_reporting (E_WARNING);
			break;
		case 3:
			error_reporting (E_PARSE);
			break;
		case 4:
			error_reporting (E_NOTICE);
			break;
		case 5:
			error_reporting (E_ALL);
			break;
		default:
			error_reporting (E_ALL);
			break;
	}
}

set_error_reporting();

function phpErrorHandle ($errno, $errstr, $errfile, $errline)
{
	global $config;

	$message = "Emilda has caused an error on " . date ("r") . ":\n\n";
	$message .= "ERROR $errno at " . $_SERVER['SERVER_NAME'] . ", $errfile [$errline]: $errstr\n";

        $headers = "From: Emilda <no-reply@" . $_SERVER['SERVER_NAME'] . ">\r\n";

        mail($config['admin_mail'], "Emilda Error", $message, $headers);
}

if (!$config['debug']) {
		set_error_handler ("phpErrorHandle");
}

function error_kill()
{
	if(isset($_REQUEST['id']))
	{
		$sql = "SELECT session_user_id FROM sessions WHERE session_id=" . $_REQUEST['id'];
		$sqlResult = mysql_query($sql);
		$row = mysql_fetch_array($sqlResult);

		session_terminate($row['session_user_id']);
	}
}

function error($error)
{
	global	$config,
			$site_config,
			$langText;

	if (empty($langText))
	{
		if(defined("USER_LANG"))
			parseLang(USER_LANG);
		else
			parseLang($config['language']);
	}

	switch($error)
	{
		case "no session":
			error_layout($langText['SEVERE_ERROR_NO_SESSION'], $site_config['home'], $langText['SEVERE_ERROR_LOGIN']);
			exit;
			break;

		case "session violation":
			error_kill();
			error_layout($langText['SEVERE_ERROR_SESSION_VIOLATION'], $site_config['home'], $langText['SEVERE_ERROR_LOGIN']);
			exit;
			break;

		case "session create fail":
			error_layout($langText['SEVERE_ERROR_SESSION_CREATE_FAIL'], $site_config['home'], $langText['SEVERE_ERROR_RETRY']);
			exit;
			break;

		case "session timeout":
			error_layout($langText['SEVERE_ERROR_SESSION_TIMEOUT'] . " (" . $config['session_timeout'] . " " . $langText['SEVERE_ERROR_SECONDS'] . ")!", $site_config['home'], $langText['SEVERE_ERROR_RELOGIN']);
			exit;
			break;

		case "login fail":
			error_layout($langText['SEVERE_ERROR_LOGIN_FAIL'], $site_config['home'], $langText['SEVERE_ERROR_RETRY']);
			exit;
			break;

		case "no priv":
			error_kill();
			error_layout($langText['SEVERE_ERROR_NO_PRIV'], $site_config['home'], $langText['SEVERE_ERROR_RELOGIN']);
			exit;
			break;

		case "unknown priv":
			error_kill();
			error_layout($langText['SEVERE_ERROR_UNKNOWN_PRIV'], $site_config['home'], $langText['SEVERE_ERROR_RELOGIN']);
			exit;
			break;

		case "config error":
			error_kill();
			error_layout($langText['SEVERE_ERROR_CONFIG_ERROR'], $site_config['home'], $langText['SEVERE_ERROR_RELOGIN']);
			exit;
			break;

		case "account disabled":
			error_kill();
			error_layout($langText['SEVERE_ERROR_ACCOUNT_DISABLED'], $site_config['home'], $langText['SEVERE_ERROR_RETRY']);
			exit;
			break;

		case "logout failure":
			error_kill();
			error_layout($langText['SEVERE_ERROR_LOGOUT_FAILURE'], $site_config['home'], $langText['SEVERE_ERROR_LOGIN']);
			exit;

		default:
			error_kill();
			error_layout($langText['SEVERE_ERROR_UNDEFINED'], $site_config['home'], $langText['SEVERE_ERROR_RELOGIN']);
			exit;
			break;
	}
}

function error_layout($errorText = '', $errorLink = '', $errorLinkText = '', $redirect = TRUE)
{
	global	$langText,
			$site_config,
			$config;

	if ($errorLink == '') {
		$errorLink = $site_config['home'];
	}

	if ($errorLinkText == '') {
		$errorLinkText = $langText['SEVERE_ERROR_LOGIN'];
	}

	if ($redirect)
	{
		require_once "layout.inc";

		print "
			<form name='error_form' action='error.php' method='post'>
				<input type='hidden' name='text' value=\"$errorText\" />
				<input type='hidden' name='link' value=\"$errorLink\" />
				<input type='hidden' name='linktext' value=\"$errorLinkText\" />
			</form>
			<script language='JavaScript'>document.error_form.submit();</script>
		";
	}

	//print ugly message if JS redirect fails

	$content = '';

	$filename = "templates/" . $config['template'] . "/layout_error";

	if (!file_exists($filename)) {
		$filename = "templates/default/layout_error";
	}

	$filecontent = file($filename, 1);
	foreach($filecontent as $line)
	{
		if(substr($line, 0, 1) == "#")
			continue;

		$content .= $line;
	}

	$content = str_replace('%errortext%', $errorText, $content);
	$content = str_replace('%errorlink%', "<a href='$errorLink'>$errorLinkText</a>", $content);

	print $content;
}

?>
